rusclasp
========

Clause splitter for Russian language.

.. image:: https://readthedocs.org/projects/rusclasp/badge/?version=latest
  :target: http://rusclasp.readthedocs.io/ru/latest/
  :alt: Documentation Status
.. image:: https://badge.fury.io/py/rusclasp.svg
   :target: https://badge.fury.io/py/rusclasp
.. image:: https://img.shields.io/pypi/wheel/Django.svg?maxAge=2592000
  :target: https://pypi.python.org/pypi/rusclasp
.. image:: https://img.shields.io/github/license/mashape/apistatus.svg?maxAge=2592000
  :target: https://github.com/gree-gorey/rusclasp/blob/master/LICENCE.md
.. image:: https://zenodo.org/badge/19768/gree-gorey/rusclasp.svg
  :target: https://zenodo.org/badge/latestdoi/19768/gree-gorey/rusclasp

|

* changelog: https://github.com/gree-gorey/rusclasp/blob/master/CHANGES.rst
* source code: github_
* bug tracker: https://github.com/gree-gorey/rusclasp/issues

.. _github: https://github.com/gree-gorey/rusclasp